pub type ReentrantMutex<T> = ReentrantMutex<RawMutex, RawThreadId, T>;๐Deprecated:
The parkinglot feature has been renamed parking_lot
Dependency tracking reentrant mutex. See: ::parking_lot::ReentrantMutex.
Note: due to the way dependencies are tracked, this mutex can only be acquired directly after itself. Acquiring any other mutex in between introduces a dependency cycle, and will therefore be rejected.
Aliased Type
pub struct ReentrantMutex<T> { /* private fields */ }